diff --git a/twitter_block.module b/twitter_block.module
index 13cceba..f7a52fe 100644
--- a/twitter_block.module
+++ b/twitter_block.module
@@ -207,7 +207,8 @@ function twitter_block_preprocess_twitter_block_tweet(&$variables) {
   $variables['text'] = twitter_block_linkify($variables['tweet']->text);
   $variables['date'] = format_date(strtotime($variables['tweet']->created_at));
   $variables['user_image'] = ($variables['api'] == 'rest') ? $variables['tweet']->user->profile_image_url : $variables['tweet']->profile_image_url;
-  $variables['user_name'] = ($variables['api'] == 'rest') ? $variables['tweet']->user->screen_name : $variables['tweet']->from_user;
+  $variables['name'] = ($variables['api'] == 'rest') ? $variables['tweet']->user->name : $variables['tweet']->from_user_name;
+  $variables['screen_name'] = ($variables['api'] == 'rest') ? $variables['tweet']->user->screen_name : $variables['tweet']->from_user;
 }
 
 /**

diff --git a/twitter-block-tweet.tpl.php b/twitter-block-tweet.tpl.php
index 2a12cae..6129316 100644
--- a/twitter-block-tweet.tpl.php
+++ b/twitter-block-tweet.tpl.php
@@ -7,7 +7,8 @@
  * A list of tweets are displayed inside of the twitter block.
  *
  * Available variables:
  * - $user_name: The screen name of the tweet's author.
  * - $user_image: A URL to the tweet's author's profile picture.
  * - $date: The tweet's creation date.
  * - $text: The tweet's text.
@@ -15,9 +16,9 @@
 ?>
 <div class="clearfix tweet twitter_block">
   <div class="twitter_block_user">
-    <a class="twitter_block profile_image" href="http://twitter.com/<?php echo $user_name; ?>">
+    <a class="twitter_block profile_image" href="http://twitter.com/<?php echo $screen_name; ?>">
       <img src="<?php echo $user_image; ?>" alt="Twitter Avatar" />
-      <span class="twitter_block_user_name"><?php echo $user_name; ?></span>
+      <span class="twitter_block_user_name"><?php echo $name; ?></span>
     </a>
   </div>
   <div class="tweet_date"><?php echo $date; ?></div>
@@ -7,7 +7,8 @@
  *
  * Available variables:
- * - $user_name: The screen name of the tweet's author.
+ * - $name: The name of the tweet's author.
+ * - $screen_name: The screen name of the tweet's author.
  * - $user_image: A URL to the tweet's author's profile picture.
  * - $date: The tweet's creation date.